@@ -171,14 +171,15 @@ Channel::Channel(QWidget* parent, const QString& _name) : ChatWindow(parent)
     modeK->setWhatsThis(ChannelOptionsDialog::whatsThisForMode('K'));
     modeL->setWhatsThis(ChannelOptionsDialog::whatsThisForMode('L'));
 
-    connect(modeT,SIGNAL(clicked(int,bool)),this,SLOT(modeButtonClicked(int,bool)));
-    connect(modeN,SIGNAL(clicked(int,bool)),this,SLOT(modeButtonClicked(int,bool)));
-    connect(modeS,SIGNAL(clicked(int,bool)),this,SLOT(modeButtonClicked(int,bool)));
-    connect(modeI,SIGNAL(clicked(int,bool)),this,SLOT(modeButtonClicked(int,bool)));
-    connect(modeP,SIGNAL(clicked(int,bool)),this,SLOT(modeButtonClicked(int,bool)));
-    connect(modeM,SIGNAL(clicked(int,bool)),this,SLOT(modeButtonClicked(int,bool)));
-    connect(modeK,SIGNAL(clicked(int,bool)),this,SLOT(modeButtonClicked(int,bool)));
-    connect(modeL,SIGNAL(clicked(int,bool)),this,SLOT(modeButtonClicked(int,bool)));
+    connect(modeT, &ModeButton::modeClicked, this, &Channel::modeButtonClicked);
+    connect(modeN, &ModeButton::modeClicked, this, &Channel::modeButtonClicked);
+    connect(modeS, &ModeButton::modeClicked, this, &Channel::modeButtonClicked);
+    connect(modeI, &ModeButton::modeClicked, this, &Channel::modeButtonClicked);
+    connect(modeP, &ModeButton::modeClicked, this, &Channel::modeButtonClicked);
+    connect(modeM, &ModeButton::modeClicked, this, &Channel::modeButtonClicked);
+    connect(modeK, &ModeButton::modeClicked, this, &Channel::modeButtonClicked);
+    connect(modeL, &ModeButton::modeClicked, this, &Channel::modeButtonClicked);
+    connect(modeT, &ModeButton::modeClicked, this, &Channel::modeButtonClicked);
 
     limit=new KLineEdit(modeBox);
     modeBoxLayout->addWidget(limit);
@@ -292,7 +293,7 @@ Channel::Channel(QWidget* parent, const QString& _name) : ChatWindow(parent)
     connect(nicknameCombobox,SIGNAL (activated(int)),this,SLOT(nicknameComboboxChanged()));
 
     if(nicknameCombobox->lineEdit())
-        connect(nicknameCombobox->lineEdit(), SIGNAL (editingFinished()),this,SLOT(nicknameComboboxChanged()));
+        connect(nicknameCombobox->lineEdit(), SIGNAL (returnPressed()),this,SLOT(nicknameComboboxChanged()));
 
 
     connect(&userhostTimer,SIGNAL (timeout()),this,SLOT (autoUserhost()));
@@ -971,8 +972,8 @@ void Channel::addNickname(ChannelNickPtr channelnick)
         adjustNicks(1);
         requestNickListSort();
     }
-    else
-        qWarning() << "Nickname " << channelnick->getNickname() << " has not been added as it is already in the nickname list."<< endl;
+    // TODO (re)-investigate why it was thought unusual to add an already added nick
+    // -- see bug 333969
 }
 
 // Use with caution! Does not check for duplicates or may not
