@@ -72,10 +72,10 @@ IrcContextMenus::IrcContextMenus()
     createSharedNickSettingsActions();
     createSharedDccActions();
 
-    setupChannelMenu();
     setupQuickButtonMenu();
     setupNickMenu();
-    setupTextMenu();
+    setupTextMenu(); // creates m_textCopyAction needed by the channel menu
+    setupChannelMenu();
     setupTopicHistoryMenu();
 
     updateQuickButtonMenu();
@@ -83,11 +83,14 @@ IrcContextMenus::IrcContextMenus()
 
 IrcContextMenus::~IrcContextMenus()
 {
-    delete m_textMenu;
     delete m_channelMenu;
+    delete m_textMenu;
     delete m_nickMenu;
     delete m_quickButtonMenu;
     delete m_topicHistoryMenu;
+    delete m_modesMenu;
+    delete m_kickBanMenu;
+    delete m_webShortcutsMenu;
 }
 
 IrcContextMenus* IrcContextMenus::self()
@@ -167,7 +170,7 @@ void IrcContextMenus::setupTextMenu()
     action->setData(TextSelectAll);
     m_textMenu->addAction(action);
 
-    m_webShortcutsMenu = new QMenu(m_textMenu);
+    m_webShortcutsMenu = new QMenu();
     m_webShortcutsMenu->menuAction()->setIcon(QIcon::fromTheme("preferences-web-browser-shortcuts"));
     m_webShortcutsMenu->menuAction()->setVisible(false);
     m_textMenu->addMenu(m_webShortcutsMenu);
@@ -346,6 +349,8 @@ void IrcContextMenus::setupChannelMenu()
 
     createAction(m_channelMenu, Topic, i18n("Get &topic"));
     createAction(m_channelMenu, Names, i18n("Get &user list"));
+    
+    m_channelMenu->addAction(m_textCopyAction);
 }
 
 void IrcContextMenus::channelMenu(const QPoint& pos, Server* server, const QString& channel)
@@ -362,6 +367,8 @@ void IrcContextMenus::channelMenu(const QPoint& pos, Server* server, const QStri
 
     QAction* action = channelMenu->exec(pos);
 
+    self()->m_textCopyAction->setEnabled(false);
+    
     switch (extractActionId(action))
     {
         case Join:
@@ -373,6 +380,9 @@ void IrcContextMenus::channelMenu(const QPoint& pos, Server* server, const QStri
         case Names:
             commandToServer(server, "names " + channel);
             break;
+        case TextCopy:
+            qApp->clipboard()->setText(channel, QClipboard::Clipboard);
+            break;
         default:
             break;
     }
@@ -392,7 +402,7 @@ void IrcContextMenus::setupNickMenu()
 
     m_nickMenu->addSeparator();
 
-    m_modesMenu = new QMenu(m_nickMenu);
+    m_modesMenu = new QMenu();
     m_nickMenu->addMenu(m_modesMenu);
     m_modesMenu->setTitle(i18n("Modes"));
     createAction(m_modesMenu, GiveOp, QIcon::fromTheme("irc-operator"), i18n("Give Op"));
@@ -402,7 +412,7 @@ void IrcContextMenus::setupNickMenu()
     createAction(m_modesMenu, GiveVoice, QIcon::fromTheme("irc-voice"), i18n("Give Voice"));
     createAction(m_modesMenu, TakeVoice, QIcon::fromTheme("irc-unvoice"), i18n("Take Voice"));
 
-    m_kickBanMenu = new QMenu(m_nickMenu);
+    m_kickBanMenu = new QMenu();
     m_nickMenu->addMenu(m_kickBanMenu);
     m_kickBanMenu->setTitle(i18n("Kick / Ban"));
     createAction(m_kickBanMenu, Kick, i18n("Kick"));
@@ -454,7 +464,7 @@ void IrcContextMenus::createSharedNickSettingsActions()
 
 void IrcContextMenus::createSharedDccActions()
 {
-    if (KAuthorized::authorizeKAction("allow_downloading"))
+    if (KAuthorized::authorizeAction("allow_downloading"))
         m_sharedDccActions << createAction(DccSend, QIcon::fromTheme("arrow-right-double"), i18n("Send &File..."));
 
     m_sharedDccActions << createAction(StartDccChat, i18n("Open DCC Chat"));
